from celery.signals import task_prerun, worker_init
from pgdatalogger.utils import set_session_data


def on_task_prerun(sender=None, task_id=None, task=None, args=None, **kw):
    if task:
        # при подключенном production_request эти параметры будет в задаче
        request_id = task.production_request_uuid or ''
        user = getattr(task, 'user', None)
        user_id = user.id if user else ''
        path = getattr(task, 'path', getattr(task, 'name', ''))
        # подготовим объект для сохранения данных о сессии
        session_data = {
            'id': request_id,
            'user': user_id,
            'path': path,
            'is_celery': True,
        }
        set_session_data(session_data)


def on_worker(sender, **kwargs):
    """
    Обработчик старта воркера.
    Навешиваем обработчик задач, который будет проставлять параметры сессии.
    """
    # Навешиваем тут, чтобы он был зарегистрирован одним из последних, чтобы
    # соединения с БД уже было закрыто до этого обработчика
    task_prerun.connect(on_task_prerun)


worker_init.connect(on_worker)
